==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/liblxqt/liblxqt_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="70"/>
        <source>LXQt Power Manager Error</source>
        <translation>Ошибка управления энергопотреблением LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="70"/>
        <source>Hibernate failed.</source>
        <translation>Ошибка перехода в спящий режим.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>Резервный вариант уведомлений</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="112"/>
        <source>Hibernate</source>
        <translation>Спящий режим</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="119"/>
        <source>Suspend</source>
        <translation>Ждущий режим</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="126"/>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="133"/>
        <source>Shutdown</source>
        <translation>Выключить компьютер</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="140"/>
        <source>Logout</source>
        <translation>Завершить сеанс</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="152"/>
        <source>LXQt Session Suspend</source>
        <translation>Ждущий режим сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="153"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Перевести компьютер в ждущий режим?&lt;p&gt;Переводит компьютер в режим низкого энергопотрбления. В случае отключения питания состояние системы будет потеряно.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="162"/>
        <source>LXQt Session Hibernate</source>
        <translation>Спящий режим сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="163"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Перевести компьютер в спящий режим?&lt;p&gt;Переводит компьютер в режим низкого энергопотрбления. Состояние системы будет сохранено при отключении питания.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="172"/>
        <source>LXQt Session Reboot</source>
        <translation>Перезагрузка сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="173"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Перезагрузить компьютер? Все несохранённые изменения в документах будут потеряны...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="182"/>
        <source>LXQt Session Shutdown</source>
        <translation>Выключение сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="183"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Выключить компьютер? Все несохранённые изменения в документах будут потеряны...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="192"/>
        <source>LXQt Session Logout</source>
        <translation>Завершение сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="193"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Завершить сеанс? Все несохранённые изменения в документах будут потеряны...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="201"/>
        <location filename="../lxqtpowermanager.cpp" line="206"/>
        <source>LXQt Power Manager Error</source>
        <translation>Ошибка управления энергопотреблением LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="201"/>
        <source>Hibernate failed.</source>
        <translation>Ошибка перехода в спящий режим.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="206"/>
        <source>Suspend failed.</source>
        <translation>Ошибка перехода в ждущий режим.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="51"/>
        <source>Lock Screen</source>
        <translation>Заблокировать экран</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="77"/>
        <source>Screen Saver Error</source>
        <translation>Ошибка хранителя экрана</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="83"/>
        <location filename="../lxqtscreensaver.cpp" line="89"/>
        <location filename="../lxqtscreensaver.cpp" line="96"/>
        <source>Screen Saver Activation Error</source>
        <translation>Ошибка запуска хранителя экрана</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="97"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>При запуске хранителя экрана произошла ошибка. Неизвестная ошибка - недокументированный код возврата xdg-screensaver: %1.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="78"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>При запуске хранителя экрана произошла ошибка. Неверные аргументы запуска xdg-screensaver.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="84"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>При запуске хранителя экрана произошла ошибка. Убедитесь, что xscreensaver установлен и запущен.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="90"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>При запуске хранителя экрана произошла ошибка. Невозможно выполнить действие «запустить». Убедитесь, что xscreensaver установлен и запущен.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="91"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="141"/>
        <source>Power Manager Error</source>
        <translation>Ошибка управления энергопотреблением</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="92"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="142"/>
        <source>QDBusInterface is invalid</source>
        <translation>Неправильный интерфейс доступа к шине DBus</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="106"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="156"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Ошибка управления энергопотреблением (вызов D-BUS)</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/liblxqt/liblxqt_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>LXQt Power Manager Error</source>
        <translation>Ошибка управления энергопотреблением LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="70"/>
        <source>Hibernate failed.</source>
        <translation>Ошибка перехода в спящий режим.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../../lxqtnotification.cpp" line="152"/>
        <source>Notifications Fallback</source>
        <translation>Резервный вариант уведомлений</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="112"/>
        <source>Hibernate</source>
        <translation>Спящий режим</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="119"/>
        <source>Suspend</source>
        <translation>Ждущий режим</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="126"/>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="133"/>
        <source>Shutdown</source>
        <translation>Выключить компьютер</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="140"/>
        <source>Logout</source>
        <translation>Завершить сеанс</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="152"/>
        <source>LXQt Session Suspend</source>
        <translation>Ждущий режим сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="153"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Перевести компьютер в ждущий режим?&lt;p&gt;Переводит компьютер в режим низкого энергопотрбления. В случае отключения питания состояние системы будет потеряно.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="162"/>
        <source>LXQt Session Hibernate</source>
        <translation>Спящий режим сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="163"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Перевести компьютер в спящий режим?&lt;p&gt;Переводит компьютер в режим низкого энергопотрбления. Состояние системы будет сохранено при отключении питания.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="172"/>
        <source>LXQt Session Reboot</source>
        <translation>Перезагрузка сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="173"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Перезагрузить компьютер? Все несохранённые изменения в документах будут потеряны...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="182"/>
        <source>LXQt Session Shutdown</source>
        <translation>Выключение сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="183"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Выключить компьютер? Все несохранённые изменения в документах будут потеряны...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="192"/>
        <source>LXQt Session Logout</source>
        <translation>Завершение сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="193"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Завершить сеанс? Все несохранённые изменения в документах будут потеряны...</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>LXQt Power Manager Error</source>
        <translation>Ошибка управления энергопотреблением LXQt</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="201"/>
        <source>Hibernate failed.</source>
        <translation>Ошибка перехода в спящий режим.</translation>
    </message>
    <message>
        <location filename="../../lxqtpowermanager.cpp" line="206"/>
        <source>Suspend failed.</source>
        <translation>Ошибка перехода в ждущий режим.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="51"/>
        <source>Lock Screen</source>
        <translation>Заблокировать экран</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="77"/>
        <source>Screen Saver Error</source>
        <translation>Ошибка хранителя экрана</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="83"/>
        <location filename="../../lxqtscreensaver.cpp" line="89"/>
        <location filename="../../lxqtscreensaver.cpp" line="96"/>
        <source>Screen Saver Activation Error</source>
        <translation>Ошибка запуска хранителя экрана</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="97"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>При запуске хранителя экрана произошла ошибка. Неизвестная ошибка - недокументированный код возврата xdg-screensaver: %1.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="78"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>При запуске хранителя экрана произошла ошибка. Неверные аргументы запуска xdg-screensaver.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="84"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>При запуске хранителя экрана произошла ошибка. Убедитесь, что xscreensaver установлен и запущен.</translation>
    </message>
    <message>
        <location filename="../../lxqtscreensaver.cpp" line="90"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>При запуске хранителя экрана произошла ошибка. Невозможно выполнить действие «запустить». Убедитесь, что xscreensaver установлен и запущен.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="91"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="141"/>
        <source>Power Manager Error</source>
        <translation>Ошибка управления энергопотреблением</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="92"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="142"/>
        <source>QDBusInterface is invalid</source>
        <translation>Неправильный интерфейс доступа к шине DBus</translation>
    </message>
    <message>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="106"/>
        <location filename="../../lxqtpower/lxqtpowerproviders.cpp" line="156"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Ошибка управления энергопотреблением (вызов D-BUS)</translation>
    </message>
</context>
</TS>
